##  How to Model Organization Organized Based on Regions and Business Units
In this example, we used a free draw diagram to create a visualization that shows an overview of regions and business units with applications linked to those:
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274e10847a441014aef5dba9f99b91b7_LowRes.png)
